@@ -8,7 +8,7 @@ sub PROTOCOL_VERSION_1_0A() {1.001}
 
 sub OAUTH_VERSION() {'1.0'}
 
-our $VERSION = '0.27';
+our $VERSION = '0.30';
 our $SKIP_UTF8_DOUBLE_ENCODE_CHECK = 0;
 our $PROTOCOL_VERSION = PROTOCOL_VERSION_1_0;
 
@@ -58,80 +58,67 @@ sub smart_require {
 
 =head1 NAME
 
-Net::OAuth - OAuth protocol support
+Net::OAuth - OAuth 1.0 for Perl
 
 =head1 SYNOPSIS
 
-    # Consumer sends Request Token Request
+  # Web Server Example (Dancer)
 
-    use Net::OAuth;
-    $Net::OAuth::PROTOCOL_VERSION = Net::OAuth::PROTOCOL_VERSION_1_0A;
-    use HTTP::Request::Common;
-    my $ua = LWP::UserAgent->new;
+  # This example is simplified for illustrative purposes, see the complete code in /demo
 
-    my $request = Net::OAuth->request("request token")->new(
-        consumer_key => 'dpf43f3p2l4k3l03',
-        consumer_secret => 'kd94hf93k423kf44',
-        request_url => 'https://photos.example.net/request_token',
-        request_method => 'POST',
-        signature_method => 'HMAC-SHA1',
-        timestamp => '1191242090',
-        nonce => 'hsu94j3884jdopsl',
-        callback => 'http://printer.example.com/request_token_ready',
-        extra_params => {
-            apple => 'banana',
-            kiwi => 'pear',
-        }
-    );
+  # Note that client_id is the Consumer Key and client_secret is the Consumer Secret
 
-    $request->sign;
+  use Dancer;
+  use Net::OAuth::Client;
 
-    my $res = $ua->request(POST $request->to_url); # Post message to the Service Provider
+  sub client {
+  	Net::OAuth::Client->new(
+  		config->{client_id},
+  		config->{client_secret},
+  		site => 'https://www.google.com/',
+  		request_token_path => '/accounts/OAuthGetRequestToken?scope=https%3A%2F%2Fwww.google.com%2Fm8%2Ffeeds%2F',
+  		authorize_path => '/accounts/OAuthAuthorizeToken',
+  		access_token_path => '/accounts/OAuthGetAccessToken',
+  		callback => uri_for("/auth/google/callback"),
+  		session => \&session,
+  	);
+  }
 
-    if ($res->is_success) {
-        my $response = Net::OAuth->response('request token')->from_post_body($res->content);
-        print "Got Request Token ", $response->token, "\n";
-        print "Got Request Token Secret ", $response->token_secret, "\n";
-    }
-    else {
-        die "Something went wrong";
-    }
+  # Send user to authorize with service provider
+  get '/auth/google' => sub {
+  	redirect client->authorize_url;
+  };
 
-    # Etc..
+  # User has returned with token and verifier appended to the URL.
+  get '/auth/google/callback' => sub {
 
-    # Service Provider receives Request Token Request
+  	# Use the auth code to fetch the access token
+  	my $access_token =  client->get_access_token(params->{oauth_token}, params->{oauth_verifier});
 
-    use Net::OAuth;
-    $Net::OAuth::PROTOCOL_VERSION = Net::OAuth::PROTOCOL_VERSION_1_0A;
-    use CGI;
-    my $q = new CGI;
+  	# Use the access token to fetch a protected resource
+  	my $response = $access_token->get('/m8/feeds/contacts/default/full');
 
-    my $request = Net::OAuth->request("request token")->from_hash({$q->Vars},
-        request_url => 'https://photos.example.net/request_token',
-        request_method => $q->request_method,
-        consumer_secret => 'kd94hf93k423kf44',
-    );
+  	# Do something with said resource...
 
-    if (!$request->verify) {
-        die "Signature verification failed";
-    }
-    else {
-        # Service Provider sends Request Token Response
+  	if ($response->is_success) {
+  	  return "Yay, it worked: " . $response->decoded_content;
+  	}
+  	else {
+  	  return "Error: " . $response->status_line;
+  	}
+  };
 
-        my $response = Net::OAuth->response("request token")->new( 
-            token => 'abcdef',
-            token_secret => '0123456',
-            callback_confirmed => 'true',
-        );
+  dance;
 
-        print $response->to_post_body;
-    }    
+=head1 IMPORTANT
 
-    # Etc..
+Net::OAuth provides a low-level API for reading and writing OAuth messages.
+
+You probably should start with L<Net::OAuth::Client>.
 
 =head1 ABSTRACT
 
-OAuth is 
+OAuth is
 
 "An open protocol to allow secure API authentication in a simple and standard method from desktop and web applications."
 
@@ -143,13 +130,13 @@ Net::OAuth provides:
 
 =over
 
-=item * classes that encapsulate OAuth messages (requests and responses).  
+=item * classes that encapsulate OAuth messages (requests and responses).
 
 =item * message signing
 
 =item * message serialization and parsing.
 
-=item * 2-legged requests (aka. tokenless requests, aka. consumer requests), see L</"CONSUMER REQUESTS"> 
+=item * 2-legged requests (aka. tokenless requests, aka. consumer requests), see L</"CONSUMER REQUESTS">
 
 =back
 
@@ -157,7 +144,7 @@ Net::OAuth does not provide:
 
 =over
 
-=item * Consumer or Service Provider encapsulation  
+=item * Consumer or Service Provider encapsulation
 
 =item * token/nonce/key storage/management
 
@@ -210,7 +197,7 @@ To create a message, the easiest way is to use the factory methods (Net::OAuth->
 
 The more verbose way is to use the class directly:
 
- use Net::OAuth::UserAuthRequest; 
+ use Net::OAuth::UserAuthRequest;
  $request = Net::OAuth::UserAuthRequest->new(%params);
 
 You can also create a message by deserializing it from a Authorization header, URL, query hash, or POST body
@@ -311,6 +298,8 @@ The following signature methods are supported:
 
 =item * HMAC-SHA1
 
+=item * HMAC-SHA256
+
 =item * RSA-SHA1
 
 =back
@@ -327,6 +316,10 @@ This method is a trivial signature which adds no security.  Not recommended.
 
 This method is available if you have Digest::HMAC_SHA1 installed.  This is by far the most commonly used method.
 
+=head3 HMAC-SHA256 SIGNATURES
+
+This method is available if you have Digest::SHA installed.
+
 =head3 RSA-SHA1 SIGNATURES
 
 To use RSA-SHA1 signatures, pass in a Crypt::OpenSSL::RSA object (or any object that can do $o->sign($str) and/or $o->verify($str, $sig))
@@ -341,7 +334,7 @@ Consumer:
  $private_key = Crypt::OpenSSL::RSA->new_private_key($keystring);
  $request = Net::OAuth->request('request token')->new(%params);
  $request->sign($private_key);
- 
+
 Service Provider:
 
  use Crypt::OpenSSL::RSA;
@@ -375,7 +368,7 @@ See L<Net::OAuth::ConsumerRequest>
 
 =head2 I18N
 
-Per the OAuth spec, when making the signature Net::OAuth first encodes parameters to UTF-8. This means that any parameters you pass to Net::OAuth, if they might be outside of ASCII character set, should be run through Encode::decode() (or an equivalent PerlIO layer) first to decode them to Perl's internal character sructure.
+Per the OAuth spec, when making the signature Net::OAuth first encodes parameters to UTF-8. This means that any parameters you pass to Net::OAuth, if they might be outside of ASCII character set, should be run through Encode::decode() (or an equivalent PerlIO layer) first to decode them to Perl's internal character structure.
 
 =head2 OAUTH 1.0A
 
@@ -392,8 +385,8 @@ Net::OAuth defaults to OAuth 1.0 spec compliance, and supports OAuth 1.0 Rev A w
 
 It is recommended that any new projects use this switch if possible, and existing projects move to supporting this switch as soon as possible.  Probably the easiest way for existing projects to do this is to turn on the switch and run your test suite.  The Net::OAuth constructor will throw an exception where the new protocol parameters (callback, callback_confirmed, verifier) are missing.
 
-Internally, the Net::OAuth::Message constructor checks $Net::OAuth::PROTOCOL_VERSION and attempts to load the equivalent subclass in the Net::OAuth::V1_0A:: namespace.  So if you instantiate a Net::OAuth::RequestTokenRequest object, you will end up with a Net::OAuth::V1_0A::RequestTokenRequest (a subclass of Net::OAuth::RequestTokenRequest) if the protocol version is set to PROTOCOL_VERSION_1_0A.  You can also select a 1.0a subclass on a per-message basis by passing 
-    
+Internally, the Net::OAuth::Message constructor checks $Net::OAuth::PROTOCOL_VERSION and attempts to load the equivalent subclass in the Net::OAuth::V1_0A:: namespace.  So if you instantiate a Net::OAuth::RequestTokenRequest object, you will end up with a Net::OAuth::V1_0A::RequestTokenRequest (a subclass of Net::OAuth::RequestTokenRequest) if the protocol version is set to PROTOCOL_VERSION_1_0A.  You can also select a 1.0a subclass on a per-message basis by passing
+
     protocol_version => Net::OAuth::PROTOCOL_VERSION_1_0A
 
 in the API parameters hash.
@@ -408,7 +401,7 @@ If you are not sure whether the entity you are communicating with is 1.0A compli
         if ($@ =~ /Missing required parameter 'callback_confirmed'/) {
             # fall back to OAuth 1.0
             $response = Net::OAuth->response('request token')->from_post_body(
-                $res->content, 
+                $res->content,
                 protocol_version => Net::OAuth::PROTOCOL_VERSION_1_0
             );
             $is_oauth_1_0 = 1; # from now on treat the server as OAuth 1.0 compliant
@@ -443,18 +436,18 @@ Check out L<WWW::Netflix::API> for a Netflix-specific OAuth API
 =item * Add convenience methods for SPs
 
 Something like:
-    
+
     # direct from CGI.pm object
     $request = Net::OAuth->request('Request Token')->from_cgi_query($cgi, %api_params);
-    
+
     # direct from Catalyst::Request object
-    $request = Net::OAuth->request('Request Token')->from_catalyst_request($c->req, %api_params); 
-    
+    $request = Net::OAuth->request('Request Token')->from_catalyst_request($c->req, %api_params);
+
     # from Auth header and GET and POST params in one
     local $/;
     my $post_body = <STDIN>;
     $request = Net::OAuth->request('Request Token')->from_auth_get_and_post(
-        $ENV{HTTP_AUTHORIZATION}, 
+        $ENV{HTTP_AUTHORIZATION},
         $ENV{QUERY_STRING},
         $post_body,
         %api_params
@@ -464,15 +457,17 @@ Something like:
 
 =head1 AUTHOR
 
-Keith Grennan, C<< <kgrennan at cpan.org> >>
+Originally by Keith Grennan <kgrennan@cpan.org>
+
+Currently maintained by Robert Rothenberg <rrwo@cpan.org>
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright 2009 Keith Grennan, all rights reserved.
+Copyright 2007-2012, 2024-2025 Keith Grennan
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
 
 =cut
 
-1;
\ No newline at end of file
+1;
